@@ -12,8 +12,7 @@ import urllib.parse as path_encoder
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
 #API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
-#API_GW = "https://csctis3kqa.execute-api.us-east-2.amazonaws.com/api/"
-API_GW = "https://eq0awyoili.execute-api.cn-north-1.amazonaws.com.cn/api/"
+API_GW = "https://lqv7opk72g.execute-api.cn-north-1.amazonaws.com.cn/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -184,4 +183,4 @@ if __name__ == "__main__":
     make_tar("yolov5")
     create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
     #make_tar("train.py")
-    #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
\ No newline at end of file
+    #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
